@@ -313,10 +313,8 @@ class LogRecord(object):
     def __init__(self, channel, level, msg, args=None, kwargs=None,
                  exc_info=None, extra=None, frame=None, dispatcher=None):
         #: the name of the logger that created it or any other textual
-        #: channel description.  This is a descriptive name and should not
-        #: be used for filtering.  A log record might have a
-        #: :attr:`dispatcher` defined which provides more information for
-        #: filtering if this is absolutely necessary.
+        #: channel description.  This is a descriptive name and can be
+        #: used for filtering.
         self.channel = channel
         #: The message of the log record as new-style format string.
         self.msg = msg
@@ -848,13 +846,14 @@ class LoggerGroup(object):
     """
 
     def __init__(self, loggers=None, level=NOTSET, processor=None):
-        if loggers is None:
-            loggers = []
         #: a list of all loggers on the logger group.  Use the
         #: :meth:`add_logger` and :meth:`remove_logger` methods to add
-        #: or remove loggers from this list, or make sure to set their
-        #: :attr:`~RecordDispatcher.group` attribute appropriately.
-        self.loggers = loggers
+        #: or remove loggers from this list.
+        self.loggers = []
+        if loggers is not None:
+            for logger in loggers:
+                self.add_logger(logger)
+
         #: the level of the group.  This is reflected to the loggers
         #: in the group unless they overrode the setting.
         self.level = lookup_level(level)
