@@ -982,6 +982,7 @@ class MailHandler(Handler, StringFormatterHandlerMixin,
         Subject: {record.level_name} on My Application
 
         {record.message}
+        {record.extra[a_custom_injected_record]}
         ''')
 
     This handler will always emit text-only mails for maximum portability and
@@ -1121,7 +1122,7 @@ class MailHandler(Handler, StringFormatterHandlerMixin,
         """
         from smtplib import SMTP, SMTP_PORT, SMTP_SSL_PORT
         if self.server_addr is None:
-            host = ''
+            host = 'localhost'
             port = self.secure and SMTP_SSL_PORT or SMTP_PORT
         else:
             host, port = self.server_addr
