@@ -15,6 +15,43 @@ from logbook.handlers import Handler, WrapperHandler
 from logbook.helpers import json
 
 
+class RabbitMQHandler(Handler):
+    """A handler that acts as a RabbitMQ publisher, which publishes each record
+    as json dump.  Requires the kombu module.
+
+    The queue will be filled with JSON exported log records.  To receive such
+    log records from a queue you can use the :class:`RabbitMQSubscriber`.
+
+
+    Example setup::
+
+        handler = RabbitMQHandler('amqp://guest:guest@localhost//', queue='my_log')
+    """
+    def __init__(self, uri=None, queue='logging', level=NOTSET,
+                filter=None, bubble=False, context=None):
+        Handler.__init__(self, level, filter, bubble)
+        try:
+            import kombu
+        except ImportError:
+            raise RuntimeError('The kombu library is required for '
+                               'the RabbitMQSubscriber.')
+        if uri:
+            connection = kombu.Connection(uri)
+
+        self.queue = connection.SimpleQueue(queue)
+
+    def export_record(self, record):
+        """Exports the record into a dictionary ready for JSON dumping.
+        """
+        return record.to_dict(json_safe=True)
+
+    def emit(self, record):
+        self.queue.put(self.export_record(record))
+
+    def close(self):
+        self.queue.close()
+
+
 class ZeroMQHandler(Handler):
     """A handler that acts as a ZeroMQ publisher, which publishes each record
     as json dump.  Requires the pyzmq library.
@@ -133,6 +170,75 @@ class SubscriberBase(object):
         return controller
 
 
+class RabbitMQSubscriber(SubscriberBase):
+    """A helper that acts as RabbitMQ subscriber and will dispatch received
+    log records to the active handler setup.  There are multiple ways to
+    use this class.
+
+    It can be used to receive log records from a queue::
+
+        subscriber = RabbitMQSubscriber('amqp://guest:guest@localhost//')
+        record = subscriber.recv()
+
+    But it can also be used to receive and dispatch these in one go::
+
+        with target_handler:
+            subscriber = RabbitMQSubscriber('amqp://guest:guest@localhost//')
+            subscriber.dispatch_forever()
+
+    This will take all the log records from that queue and dispatch them
+    over to `target_handler`.  If you want you can also do that in the
+    background::
+
+        subscriber = RabbitMQSubscriber('amqp://guest:guest@localhost//')
+        controller = subscriber.dispatch_in_background(target_handler)
+
+    The controller returned can be used to shut down the background
+    thread::
+
+        controller.stop()
+    """
+
+    def __init__(self, uri=None, queue='logging'):
+        try:
+            import kombu
+        except ImportError:
+            raise RuntimeError('The kombu library is required for '
+                               'the RabbitMQSubscriber.')
+        if uri:
+            connection = kombu.Connection(uri)
+
+        self.queue = connection.SimpleQueue(queue)
+
+    def __del__(self):
+        try:
+            self.close()
+        except AttributeError:
+            # subscriber partially created
+            pass
+
+    def close(self):
+        self.queue.close()
+
+    def recv(self, timeout=None):
+        """Receives a single record from the socket.  Timeout of 0 means nonblocking,
+        `None` means blocking and otherwise it's a timeout in seconds after which
+        the function just returns with `None`.
+        """
+        if timeout == 0:
+            try:
+                rv = self.queue.get(block=False)
+            except Exception:
+                return
+        else:
+            rv = self.queue.get(timeout=timeout)
+
+        log_record = rv.payload
+        rv.ack()
+
+        return LogRecord.from_dict(log_record)
+
+
 class ZeroMQSubscriber(SubscriberBase):
     """A helper that acts as ZeroMQ subscriber and will dispatch received
     log records to the active handler setup.  There are multiple ways to
@@ -214,7 +320,8 @@ def _fix_261_mplog():
     module is not imported by logging and as such the test in
     the util fails.
     """
-    import logging, multiprocessing
+    import logging
+    import multiprocessing
     logging.multiprocessing = multiprocessing
 
 
